@@ -1,7 +1,7 @@
 """
 Type annotations for rum service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/)
 
 Usage::
 
@@ -64,7 +64,7 @@ class Exceptions:
 class CloudWatchRUMClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/)
     """
 
     meta: ClientMeta
@@ -75,7 +75,7 @@ class CloudWatchRUMClient(BaseClient):
         CloudWatchRUMClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -83,7 +83,7 @@ class CloudWatchRUMClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#can_paginate)
         """
 
     def create_app_monitor(
@@ -100,7 +100,7 @@ class CloudWatchRUMClient(BaseClient):
         your application and sends that data to RUM.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.create_app_monitor)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#create_app_monitor)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#create_app_monitor)
         """
 
     def delete_app_monitor(self, *, Name: str) -> Dict[str, Any]:
@@ -108,7 +108,7 @@ class CloudWatchRUMClient(BaseClient):
         Deletes an existing app monitor.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.delete_app_monitor)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#delete_app_monitor)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#delete_app_monitor)
         """
 
     def generate_presigned_url(
@@ -122,7 +122,7 @@ class CloudWatchRUMClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#generate_presigned_url)
         """
 
     def get_app_monitor(self, *, Name: str) -> GetAppMonitorResponseTypeDef:
@@ -130,7 +130,7 @@ class CloudWatchRUMClient(BaseClient):
         Retrieves the complete configuration information for one app monitor.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.get_app_monitor)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#get_app_monitor)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#get_app_monitor)
         """
 
     def get_app_monitor_data(
@@ -147,7 +147,7 @@ class CloudWatchRUMClient(BaseClient):
         application, so that you can do your own processing or analysis of this data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.get_app_monitor_data)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#get_app_monitor_data)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#get_app_monitor_data)
         """
 
     def list_app_monitors(
@@ -157,7 +157,7 @@ class CloudWatchRUMClient(BaseClient):
         Returns a list of the Amazon CloudWatch RUM app monitors in the account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.list_app_monitors)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#list_app_monitors)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#list_app_monitors)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
@@ -165,7 +165,7 @@ class CloudWatchRUMClient(BaseClient):
         Displays the tags associated with a CloudWatch RUM resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#list_tags_for_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#list_tags_for_resource)
         """
 
     def put_rum_events(
@@ -182,7 +182,7 @@ class CloudWatchRUMClient(BaseClient):
         CloudWatch RUM.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.put_rum_events)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#put_rum_events)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#put_rum_events)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> Dict[str, Any]:
@@ -191,7 +191,7 @@ class CloudWatchRUMClient(BaseClient):
         resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#tag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
@@ -199,7 +199,7 @@ class CloudWatchRUMClient(BaseClient):
         Removes one or more tags from the specified resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#untag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#untag_resource)
         """
 
     def update_app_monitor(
@@ -214,7 +214,7 @@ class CloudWatchRUMClient(BaseClient):
         Updates the configuration of an existing app monitor.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.update_app_monitor)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#update_app_monitor)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#update_app_monitor)
         """
 
     @overload
@@ -223,7 +223,7 @@ class CloudWatchRUMClient(BaseClient):
     ) -> GetAppMonitorDataPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#get_paginator)
         """
 
     @overload
@@ -232,5 +232,5 @@ class CloudWatchRUMClient(BaseClient):
     ) -> ListAppMonitorsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#get_paginator)
         """
