@@ -1,7 +1,7 @@
 """
 Type annotations for rum service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rum/literals/)
 
 Usage::
 
@@ -24,8 +24,11 @@ __all__ = (
     "ListAppMonitorsPaginatorName",
     "StateEnumType",
     "TelemetryType",
+    "CloudWatchRUMServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -33,6 +36,7 @@ GetAppMonitorDataPaginatorName = Literal["get_app_monitor_data"]
 ListAppMonitorsPaginatorName = Literal["list_app_monitors"]
 StateEnumType = Literal["ACTIVE", "CREATED", "DELETING"]
 TelemetryType = Literal["errors", "http", "performance"]
+CloudWatchRUMServiceName = Literal["rum"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -64,6 +68,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -150,6 +155,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -186,6 +192,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -334,4 +341,28 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["get_app_monitor_data", "list_app_monitors"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-west-1",
+    "eu-west-2",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
